# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ActionType,
    Actor,
    ActorIdentity,
    ActorIdentityId,
    ActorIdentityType,
    AgentAutomationConfig,
    AgentRevision,
    AgentRevisionModel,
    AgentRevisionResponseStyle,
    AiAgent,
    ApiKeyAuthType,
    ApiKeyIdentity,
    ApiKeyIdentityDetails,
    BareInput,
    BareOutput,
    Baseline,
    Billing,
    BillingCycle,
    BillingCycles,
    BillingUsage,
    BlockConfigItemBoolean,
    BlockConfigItemJson,
    BlockConfigItemLlm,
    BlockConfigItemNumber,
    BlockConfigItemNumberDefaultValue,
    BlockConfigItemNumberMaximumValue,
    BlockConfigItemNumberMinimumValue,
    BlockConfigItemNumberValue,
    BlockConfigItemSelect,
    BlockConfigItemTextLong,
    BlockConfigItemTextLongValue,
    BlockConfigItemTextShort,
    BlockInput,
    BlockInputBlockConfigItem,
    BlockOutput,
    BlockOutputBlockConfigItem,
    BlockRun,
    BlockRunCompleted,
    BlockRunCompletedData,
    BlockRunCompletedEnvironment,
    BlockRunFailed,
    BlockRunFailedData,
    BlockRunFailedEnvironment,
    BlockRunStarted,
    BlockRunStartedData,
    BlockRunStartedEnvironment,
    BlockRunUsage,
    BlockStateUpdated,
    BlockStateUpdatedData,
    BlockStateUpdatedDataUpdateType,
    BlockStateUpdatedEnvironment,
    CancelResponse,
    CardDisplayField,
    Channel,
    CheckBoxColumn,
    CheckBoxColumnAutomationConfig,
    Collection,
    CollectionConfig,
    CollectionDestination,
    CollectionViewStateInput,
    CollectionViewStateInputViewsValue,
    CollectionViewStateOutput,
    CollectionViewStateOutputViewsValue,
    ColumnType,
    ColumnTypeBase,
    ColumnTypeBaseAutomationConfig,
    Condition,
    ConditionField,
    ConditionOperator,
    ConnectIntegrationRequestAuthType,
    Copilot,
    CopilotConfig,
    CopilotConfigCodeTheme,
    CopilotConfigFabValue,
    CopilotConfigMode,
    CreateIntegrationsResponse,
    CreateTagResponse,
    CronTriggerConfig,
    CronTriggerConfigAction,
    Custom,
    DailyUsage,
    DataType,
    DateTimeColumn,
    DateTimeColumnAutomationConfig,
    DefaultInput,
    DefaultOutput,
    DeleteTriggerResponse,
    DeleteViewResponse,
    Dependency,
    Dimensions,
    Document,
    DocumentCreatedBy,
    DocumentDataValue,
    DocumentLastUpdatedBy,
    DocumentResponse,
    EdgeUi,
    Environment,
    EnvironmentConfig,
    EnvironmentDeploymentConfig,
    EnvironmentDeploymentConfigRevisionLookup,
    EnvironmentDeploymentDocument,
    EventVersion,
    ExecuteTriggerResponse,
    Favor,
    FavoriteItem,
    File,
    FilesAttribute,
    FilesResponse,
    FilterOperator,
    FilterType,
    FollowupEmailRequest,
    FriendlyInvoice,
    FriendlyPaymentMethods,
    Html2Text,
    Http,
    HttpValidationError,
    Identity,
    IdentityDetails,
    IdentityTypes,
    Integration,
    IntegrationAuthType,
    IntegrationConnection,
    IntegrationConnectionAuthType,
    IntegrationConnectionIntegrationType,
    IntegrationWithConnections,
    IntegrationWithConnectionsId,
    Interval,
    IntervalTypes,
    Invoice,
    InvoiceMeta,
    InvoiceStatus,
    JsonColumn,
    JsonColumnAutomationConfig,
    KanbanViewInput,
    KanbanViewOutput,
    KanbanViewSettings,
    LegacyIdentity,
    LegacyIdentityDetails,
    LineItem,
    ListTagsResponse,
    ListTriggersResponse,
    Mapping,
    MarkDownWithContext,
    MarkdownColumn,
    MarkdownColumnAutomationConfig,
    MarkdownSplitterConfig,
    McpAuthType,
    Message,
    MessageChunk,
    ModelProvider,
    MultiPageCrawlerSettingsInput,
    MultiPageCrawlerSettingsInputScraper,
    MultiPageCrawlerSettingsInputTextExtractor,
    MultiPageCrawlerSettingsOutput,
    MultiPageCrawlerSettingsOutputScraper,
    MultiPageCrawlerSettingsOutputTextExtractor,
    MultiSelectColumn,
    MultiSelectColumnAutomationConfig,
    NodeUi,
    Notification,
    NotificationAction,
    NotificationActionType,
    NotificationSeverity,
    NotificationType,
    NotionFilterBy,
    NotionFilterOptions,
    NumberColumn,
    NumberColumnAutomationConfig,
    NumberColumnDefault,
    NumberColumnMaxValue,
    NumberColumnMinValue,
    OAuthAuthType,
    Organization,
    ParagraphSplitterConfig,
    Participant,
    ParticipantType,
    PlaceholderInput,
    PlaceholderInputType,
    PlaceholderOutput,
    PlaceholderOutputType,
    PlanTypes,
    Playwright,
    PlaywrightWaitForLoadState,
    Position,
    Prompt,
    PromptRole,
    QuerySort,
    Readability,
    RecursiveSplitterConfig,
    RelationColumn,
    RelationColumnAutomationConfig,
    ReqBody,
    RequestBody,
    ResponseModelUsage,
    Result,
    Rule,
    RulesInput,
    RulesOutput,
    RunLog,
    RunLogPagination,
    Schedule,
    SchemaResponse,
    ScoutUser,
    SelectColumn,
    SelectColumnAutomationConfig,
    SelectOptionItem,
    SentenceSplitterConfig,
    ServiceInfo,
    SinglePageCrawlerSettingsInput,
    SinglePageCrawlerSettingsInputScraper,
    SinglePageCrawlerSettingsInputTextExtractor,
    SinglePageCrawlerSettingsOutput,
    SinglePageCrawlerSettingsOutputScraper,
    SinglePageCrawlerSettingsOutputTextExtractor,
    SitemapCrawlerSettingsInput,
    SitemapCrawlerSettingsInputScraper,
    SitemapCrawlerSettingsInputTextExtractor,
    SitemapCrawlerSettingsOutput,
    SitemapCrawlerSettingsOutputScraper,
    SitemapCrawlerSettingsOutputTextExtractor,
    SlackEventResponse,
    SlackTriggerConfigInput,
    SlackTriggerConfigInputAction,
    SlackTriggerConfigOutput,
    SlackTriggerConfigOutputAction,
    SlackUrlVerification,
    SortDirection,
    SourceArchetype,
    SourceArchetypeIntegrationVersion,
    SourceSync,
    SourceSyncCrawlSettingsInput,
    SourceSyncCrawlSettingsOutput,
    SourceSyncGoogleDriveSettings,
    SourceSyncNotionSettingsInput,
    SourceSyncNotionSettingsOutput,
    SourceSyncPageCrawlSettingsInput,
    SourceSyncPageCrawlSettingsOutput,
    SourceSyncSitemapSettingsInput,
    SourceSyncSitemapSettingsOutput,
    SourceSyncWebsiteSettings,
    SourceSyncWebsiteSettingsSplitter,
    SrcAppHttpRoutesBillingBillingHourlyData,
    SrcAppHttpRoutesBillingBillingHourlyResponse,
    SrcAppHttpRoutesBillingChangeBillingPlanResponse,
    SrcAppHttpRoutesBillingCreatePortalSessionData,
    SrcAppHttpRoutesBillingCreatePortalSessionResponse,
    SrcAppHttpRoutesBillingFreePlanUsageData,
    SrcAppHttpRoutesBillingFreePlanUsageResponse,
    SrcAppHttpRoutesBillingGetBillingData,
    SrcAppHttpRoutesBillingGetBillingResponse,
    SrcAppHttpRoutesBillingGetInfoGetInfoResponse,
    SrcAppHttpRoutesBillingGetInvoicesData,
    SrcAppHttpRoutesBillingGetInvoicesResponse,
    SrcAppHttpRoutesBillingGetNotificationsResponse,
    SrcAppHttpRoutesBillingRenewPlansData,
    SrcAppHttpRoutesBillingRenewPlansResponse,
    SrcAppHttpRoutesCollectionCreateCollectionResponse,
    SrcAppHttpRoutesCollectionCreateSyncResponse,
    SrcAppHttpRoutesCollectionCreateTableResponse,
    SrcAppHttpRoutesCollectionDeleteCollectionResponse,
    SrcAppHttpRoutesCollectionDeleteDocumentsResponse,
    SrcAppHttpRoutesCollectionDeleteSyncResponse,
    SrcAppHttpRoutesCollectionDeleteTableResponse,
    SrcAppHttpRoutesCollectionGetCollectionResponse,
    SrcAppHttpRoutesCollectionGetCollectionsResponse,
    SrcAppHttpRoutesCollectionGetDocumentResponse,
    SrcAppHttpRoutesCollectionGetDocumentsResponse,
    SrcAppHttpRoutesCollectionGetSyncResponse,
    SrcAppHttpRoutesCollectionGetTableResponse,
    SrcAppHttpRoutesCollectionGetTablesResponse,
    SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel,
    SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel,
    SrcAppHttpRoutesCollectionParseFileResponse,
    SrcAppHttpRoutesCollectionSyncTableResponse,
    SrcAppHttpRoutesCollectionUpdateCollectionResponse,
    SrcAppHttpRoutesCollectionUpdateDocumentResponse,
    SrcAppHttpRoutesCollectionUpdateSyncResponse,
    SrcAppHttpRoutesCollectionUpdateTableResponse,
    SrcAppHttpRoutesInboxHandleMessageIncomingMessage,
    SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent,
    SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType,
    SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem,
    SrcAppHttpRoutesOnboardingFollowupEmailsData,
    SrcAppHttpRoutesOnboardingFollowupEmailsResponse,
    SrcAppHttpRoutesOnboardingHandleGetMeResponse,
    SrcAppHttpRoutesOnboardingHandleUpdateMeResponse,
    SrcAppHttpRoutesRootGetInfoResponse,
    SrcAppHttpRoutesTriggerCreateTriggerResponse,
    SrcAppHttpRoutesWorldInteractIncomingMessage,
    SrcAppHttpRoutesWorldInteractIncomingMessageContent,
    SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
    SrcAppHttpRoutesWorldInteractInteractionRequest,
    SrcHandlersCreateCopilotResponse,
    SrcHandlersCreateWorkflowResponse,
    SrcHandlersCreateWorkflowRevisionResponse,
    SrcHandlersDeleteCopilotResponse,
    SrcHandlersDeleteWorkflowResponse,
    SrcHandlersDeleteWorkflowRevisionResponse,
    SrcHandlersGetCopilotResponse,
    SrcHandlersGetWorkflowEnvironmentsResponse,
    SrcHandlersGetWorkflowResponse,
    SrcHandlersListCopilotsResponse,
    SrcHandlersListWorkflowRevisionsResponse,
    SrcHandlersListWorkflowsResponse,
    SrcHandlersPromoteWorkflowRevisionResponse,
    SrcHandlersUpdateCopilotResponse,
    SrcHandlersUpdateWorkflowEnvironmentResponse,
    SrcHandlersUpdateWorkflowResponse,
    StripeProvider,
    StripeProviderMeta,
    Subscription,
    Sync,
    SyncConfigInput,
    SyncConfigInputSourceSettings,
    SyncConfigOutput,
    SyncConfigOutputSourceSettings,
    Table,
    TableConfigOutput,
    TableConfigOutputSchemaItem,
    TableViewInput,
    TableViewOutput,
    TableViewSettings,
    TableViewSettingsRowHeight,
    Tag,
    TextExtractor,
    TextExtractorConfig,
    TextLongColumn,
    TextLongColumnAutomationConfig,
    TextShortColumn,
    TextShortColumnAutomationConfig,
    Tool,
    ToolsData,
    ToolsResponse,
    TrafilaturaInput,
    TrafilaturaInputTrafilaturaType,
    TrafilaturaOutput,
    TrafilaturaOutputTrafilaturaType,
    Trigger,
    TriggerStatus,
    TriggerTriggerConfig,
    TypescriptAutomationConfig,
    Units,
    UpdateCronAuthResponse,
    UpdateTagResponse,
    UpdateTriggerResponse,
    UrlColumn,
    UrlColumnAutomationConfig,
    Usage,
    UsageTypes,
    User,
    UserIdentity,
    UserIdentityDetails,
    ValidationError,
    ValidationErrorLocItem,
    ViewFilter,
    ViewListResponse,
    ViewListResponseDataItem,
    ViewQueryInput,
    ViewQueryOutput,
    ViewResponse,
    ViewResponseData,
    ViewStateResponse,
    ViewVisibility,
    Workflow,
    WorkflowActor,
    WorkflowActorType,
    WorkflowAutomationConfig,
    WorkflowConfigInput,
    WorkflowConfigOutput,
    WorkflowExecute,
    WorkflowNoteInput,
    WorkflowNoteOutput,
    WorkflowRun,
    WorkflowRunCompleted,
    WorkflowRunCompletedData,
    WorkflowRunCompletedEnvironment,
    WorkflowRunFailed,
    WorkflowRunFailedData,
    WorkflowRunFailedEnvironment,
    WorkflowRunResponse,
    WorkflowRunStarted,
    WorkflowRunStartedData,
    WorkflowRunStartedEnvironment,
    WorkflowRunStateValue,
    WorkflowRunStopReason,
    WorkflowRunStreamResponse,
)
from .errors import UnprocessableEntityError
from . import (
    collections,
    copilots,
    documents,
    environments,
    integrations,
    organizations,
    revisions,
    sources,
    syncs,
    tables,
    triggers,
    usage,
    workflow_logs,
    workflows,
)
from .client import AsyncScout, Scout
from .collections import (
    CreateViewRequestSettings,
    CreateViewRequestType,
    UpdateViewRequestSettings,
    UpdateViewRequestType,
)
from .documents import (
    DocumentsCreateRequestBody,
    DocumentsCreateRequestBodyItemValue,
    DocumentsCreateRequestBodyOneValue,
    DocumentsCreateRequestBodyZeroValue,
    DocumentsUpdateBatchRequestBody,
    DocumentsUpdateBatchRequestBodyItemValue,
    DocumentsUpdateBatchRequestBodyOneValue,
    DocumentsUpdateBatchRequestBodyZeroValue,
    DocumentsUpdateRequestValue,
)
from .environment import ScoutEnvironment
from .tables import TableConfigInputSchemaItem, TableDataSchemaItem
from .triggers import TriggersCreateRequest, TriggersExecuteSlackResponse, TriggersUpdateRequest
from .version import __version__
from .workflow_logs import WorkflowLogsListLogsResponse
from .workflows import (
    SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue,
    WorkflowsRunRequestInputsValue,
    WorkflowsRunStreamRequestInputsValue,
    WorkflowsRunWithConfigResponse,
    WorkflowsRunWithConfigResponseZero,
)

__all__ = [
    "ActionType",
    "Actor",
    "ActorIdentity",
    "ActorIdentityId",
    "ActorIdentityType",
    "AgentAutomationConfig",
    "AgentRevision",
    "AgentRevisionModel",
    "AgentRevisionResponseStyle",
    "AiAgent",
    "ApiKeyAuthType",
    "ApiKeyIdentity",
    "ApiKeyIdentityDetails",
    "AsyncScout",
    "BareInput",
    "BareOutput",
    "Baseline",
    "Billing",
    "BillingCycle",
    "BillingCycles",
    "BillingUsage",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CancelResponse",
    "CardDisplayField",
    "Channel",
    "CheckBoxColumn",
    "CheckBoxColumnAutomationConfig",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionViewStateInput",
    "CollectionViewStateInputViewsValue",
    "CollectionViewStateOutput",
    "CollectionViewStateOutputViewsValue",
    "ColumnType",
    "ColumnTypeBase",
    "ColumnTypeBaseAutomationConfig",
    "Condition",
    "ConditionField",
    "ConditionOperator",
    "ConnectIntegrationRequestAuthType",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "CreateIntegrationsResponse",
    "CreateTagResponse",
    "CreateViewRequestSettings",
    "CreateViewRequestType",
    "CronTriggerConfig",
    "CronTriggerConfigAction",
    "Custom",
    "DailyUsage",
    "DataType",
    "DateTimeColumn",
    "DateTimeColumnAutomationConfig",
    "DefaultInput",
    "DefaultOutput",
    "DeleteTriggerResponse",
    "DeleteViewResponse",
    "Dependency",
    "Dimensions",
    "Document",
    "DocumentCreatedBy",
    "DocumentDataValue",
    "DocumentLastUpdatedBy",
    "DocumentResponse",
    "DocumentsCreateRequestBody",
    "DocumentsCreateRequestBodyItemValue",
    "DocumentsCreateRequestBodyOneValue",
    "DocumentsCreateRequestBodyZeroValue",
    "DocumentsUpdateBatchRequestBody",
    "DocumentsUpdateBatchRequestBodyItemValue",
    "DocumentsUpdateBatchRequestBodyOneValue",
    "DocumentsUpdateBatchRequestBodyZeroValue",
    "DocumentsUpdateRequestValue",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "ExecuteTriggerResponse",
    "Favor",
    "FavoriteItem",
    "File",
    "FilesAttribute",
    "FilesResponse",
    "FilterOperator",
    "FilterType",
    "FollowupEmailRequest",
    "FriendlyInvoice",
    "FriendlyPaymentMethods",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "Integration",
    "IntegrationAuthType",
    "IntegrationConnection",
    "IntegrationConnectionAuthType",
    "IntegrationConnectionIntegrationType",
    "IntegrationWithConnections",
    "IntegrationWithConnectionsId",
    "Interval",
    "IntervalTypes",
    "Invoice",
    "InvoiceMeta",
    "InvoiceStatus",
    "JsonColumn",
    "JsonColumnAutomationConfig",
    "KanbanViewInput",
    "KanbanViewOutput",
    "KanbanViewSettings",
    "LegacyIdentity",
    "LegacyIdentityDetails",
    "LineItem",
    "ListTagsResponse",
    "ListTriggersResponse",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownColumnAutomationConfig",
    "MarkdownSplitterConfig",
    "McpAuthType",
    "Message",
    "MessageChunk",
    "ModelProvider",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "MultiSelectColumn",
    "MultiSelectColumnAutomationConfig",
    "NodeUi",
    "Notification",
    "NotificationAction",
    "NotificationActionType",
    "NotificationSeverity",
    "NotificationType",
    "NotionFilterBy",
    "NotionFilterOptions",
    "NumberColumn",
    "NumberColumnAutomationConfig",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "OAuthAuthType",
    "Organization",
    "ParagraphSplitterConfig",
    "Participant",
    "ParticipantType",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "PlanTypes",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "QuerySort",
    "Readability",
    "RecursiveSplitterConfig",
    "RelationColumn",
    "RelationColumnAutomationConfig",
    "ReqBody",
    "RequestBody",
    "ResponseModelUsage",
    "Result",
    "Rule",
    "RulesInput",
    "RulesOutput",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "Scout",
    "ScoutEnvironment",
    "ScoutUser",
    "SelectColumn",
    "SelectColumnAutomationConfig",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "ServiceInfo",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SlackEventResponse",
    "SlackTriggerConfigInput",
    "SlackTriggerConfigInputAction",
    "SlackTriggerConfigOutput",
    "SlackTriggerConfigOutputAction",
    "SlackUrlVerification",
    "SortDirection",
    "SourceArchetype",
    "SourceArchetypeIntegrationVersion",
    "SourceSync",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncGoogleDriveSettings",
    "SourceSyncNotionSettingsInput",
    "SourceSyncNotionSettingsOutput",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcAppHttpRoutesBillingBillingHourlyData",
    "SrcAppHttpRoutesBillingBillingHourlyResponse",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse",
    "SrcAppHttpRoutesBillingCreatePortalSessionData",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse",
    "SrcAppHttpRoutesBillingFreePlanUsageData",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse",
    "SrcAppHttpRoutesBillingGetBillingData",
    "SrcAppHttpRoutesBillingGetBillingResponse",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse",
    "SrcAppHttpRoutesBillingGetInvoicesData",
    "SrcAppHttpRoutesBillingGetInvoicesResponse",
    "SrcAppHttpRoutesBillingGetNotificationsResponse",
    "SrcAppHttpRoutesBillingRenewPlansData",
    "SrcAppHttpRoutesBillingRenewPlansResponse",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse",
    "SrcAppHttpRoutesCollectionCreateSyncResponse",
    "SrcAppHttpRoutesCollectionCreateTableResponse",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse",
    "SrcAppHttpRoutesCollectionDeleteTableResponse",
    "SrcAppHttpRoutesCollectionGetCollectionResponse",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse",
    "SrcAppHttpRoutesCollectionGetDocumentResponse",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse",
    "SrcAppHttpRoutesCollectionGetSyncResponse",
    "SrcAppHttpRoutesCollectionGetTableResponse",
    "SrcAppHttpRoutesCollectionGetTablesResponse",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel",
    "SrcAppHttpRoutesCollectionParseFileResponse",
    "SrcAppHttpRoutesCollectionSyncTableResponse",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse",
    "SrcAppHttpRoutesCollectionUpdateTableResponse",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem",
    "SrcAppHttpRoutesOnboardingFollowupEmailsData",
    "SrcAppHttpRoutesOnboardingFollowupEmailsResponse",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse",
    "SrcAppHttpRoutesRootGetInfoResponse",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse",
    "SrcAppHttpRoutesWorldInteractIncomingMessage",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem",
    "SrcAppHttpRoutesWorldInteractInteractionRequest",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "SrcHandlersWorkflowsExecuteWithConfigReqBodyInputsValue",
    "StripeProvider",
    "StripeProviderMeta",
    "Subscription",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigInputSchemaItem",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TableDataSchemaItem",
    "TableViewInput",
    "TableViewOutput",
    "TableViewSettings",
    "TableViewSettingsRowHeight",
    "Tag",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextLongColumnAutomationConfig",
    "TextShortColumn",
    "TextShortColumnAutomationConfig",
    "Tool",
    "ToolsData",
    "ToolsResponse",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "Trigger",
    "TriggerStatus",
    "TriggerTriggerConfig",
    "TriggersCreateRequest",
    "TriggersExecuteSlackResponse",
    "TriggersUpdateRequest",
    "TypescriptAutomationConfig",
    "Units",
    "UnprocessableEntityError",
    "UpdateCronAuthResponse",
    "UpdateTagResponse",
    "UpdateTriggerResponse",
    "UpdateViewRequestSettings",
    "UpdateViewRequestType",
    "UrlColumn",
    "UrlColumnAutomationConfig",
    "Usage",
    "UsageTypes",
    "User",
    "UserIdentity",
    "UserIdentityDetails",
    "ValidationError",
    "ValidationErrorLocItem",
    "ViewFilter",
    "ViewListResponse",
    "ViewListResponseDataItem",
    "ViewQueryInput",
    "ViewQueryOutput",
    "ViewResponse",
    "ViewResponseData",
    "ViewStateResponse",
    "ViewVisibility",
    "Workflow",
    "WorkflowActor",
    "WorkflowActorType",
    "WorkflowAutomationConfig",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowExecute",
    "WorkflowLogsListLogsResponse",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
    "WorkflowsRunRequestInputsValue",
    "WorkflowsRunStreamRequestInputsValue",
    "WorkflowsRunWithConfigResponse",
    "WorkflowsRunWithConfigResponseZero",
    "__version__",
    "collections",
    "copilots",
    "documents",
    "environments",
    "integrations",
    "organizations",
    "revisions",
    "sources",
    "syncs",
    "tables",
    "triggers",
    "usage",
    "workflow_logs",
    "workflows",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .actor_identity import ActorIdentity
from .agent_revision_model import AgentRevisionModel
from .agent_revision_response_style import AgentRevisionResponseStyle
from .model_provider import ModelProvider


class AgentRevision(UncheckedBaseModel):
    id: typing.Optional[str] = None
    doc_type: typing.Optional[typing.Literal["agent_revision"]] = None
    created_by: ActorIdentity
    updated_by: ActorIdentity
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    is_seed: typing.Optional[bool] = None
    parent: str
    organization_id: str
    model_provider: typing.Optional[ModelProvider] = None
    model: AgentRevisionModel
    system: str
    temperature: typing.Optional[float] = None
    response_style: typing.Optional[AgentRevisionResponseStyle] = None
    max_tokens: typing.Optional[int] = None
    max_turns: typing.Optional[int] = None
    tool_config: typing.Optional[typing.Dict[str, typing.Optional[bool]]] = None
    conversation_starters: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .src_app_http_routes_world_interact_incoming_message_content_item import (
    SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
)

SrcAppHttpRoutesWorldInteractIncomingMessageContent = typing.Union[
    str,
    typing.Dict[str, typing.Optional[typing.Any]],
    typing.List[SrcAppHttpRoutesWorldInteractIncomingMessageContentItem],
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.channel import Channel
from ..types.integration import Integration
from .raw_client import AsyncRawIntegrationsClient, RawIntegrationsClient


class IntegrationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawIntegrationsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawIntegrationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawIntegrationsClient
        """
        return self._raw_client

    def list(
        self,
        service: str,
        *,
        fetch_icons: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[Integration]:
        """
        List all OAuth integrations for the organization

        If service is 'all', returns integrations for all services.

        Parameters
        ----------
        service : str

        fetch_icons : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Integration]
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.integrations.list(
            service="service",
        )
        """
        _response = self._raw_client.list(service, fetch_icons=fetch_icons, request_options=request_options)
        return _response.data

    def list_channels(
        self, team_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Channel]:
        """
        List all channels for a specific Slack workspace

        Parameters
        ----------
        team_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Channel]
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.integrations.list_channels(
            team_id="team_id",
        )
        """
        _response = self._raw_client.list_channels(team_id, request_options=request_options)
        return _response.data


class AsyncIntegrationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawIntegrationsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawIntegrationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawIntegrationsClient
        """
        return self._raw_client

    async def list(
        self,
        service: str,
        *,
        fetch_icons: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.List[Integration]:
        """
        List all OAuth integrations for the organization

        If service is 'all', returns integrations for all services.

        Parameters
        ----------
        service : str

        fetch_icons : typing.Optional[bool]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Integration]
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.integrations.list(
                service="service",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(service, fetch_icons=fetch_icons, request_options=request_options)
        return _response.data

    async def list_channels(
        self, team_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[Channel]:
        """
        List all channels for a specific Slack workspace

        Parameters
        ----------
        team_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[Channel]
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.integrations.list_channels(
                team_id="team_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_channels(team_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.response_model_usage import ResponseModelUsage
from .raw_client import AsyncRawUsageClient, RawUsageClient


class UsageClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawUsageClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawUsageClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawUsageClient
        """
        return self._raw_client

    def get(
        self,
        *,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResponseModelUsage:
        """
        Parameters
        ----------
        start_date : typing.Optional[str]
            Start date for the usage data

        end_date : typing.Optional[str]
            End date for the usage data

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResponseModelUsage
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.usage.get()
        """
        _response = self._raw_client.get(start_date=start_date, end_date=end_date, request_options=request_options)
        return _response.data


class AsyncUsageClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawUsageClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawUsageClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawUsageClient
        """
        return self._raw_client

    async def get(
        self,
        *,
        start_date: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ResponseModelUsage:
        """
        Parameters
        ----------
        start_date : typing.Optional[str]
            Start date for the usage data

        end_date : typing.Optional[str]
            End date for the usage data

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ResponseModelUsage
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.usage.get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get(
            start_date=start_date, end_date=end_date, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .dependency import Dependency
from .node_ui import NodeUi
from .placeholder_input_type import PlaceholderInputType


class PlaceholderInput(UncheckedBaseModel):
    block_id: str
    type: PlaceholderInputType
    ui: typing.Optional[NodeUi] = None
    dependencies: typing.Optional[typing.List[Dependency]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.src_app_http_routes_collection_create_sync_response import SrcAppHttpRoutesCollectionCreateSyncResponse
from ..types.src_app_http_routes_collection_delete_sync_response import SrcAppHttpRoutesCollectionDeleteSyncResponse
from ..types.src_app_http_routes_collection_get_sync_response import SrcAppHttpRoutesCollectionGetSyncResponse
from ..types.src_app_http_routes_collection_list_collection_syncs_response_model import (
    SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel,
)
from ..types.src_app_http_routes_collection_update_sync_response import SrcAppHttpRoutesCollectionUpdateSyncResponse
from ..types.sync_config_input import SyncConfigInput
from .raw_client import AsyncRawSyncsClient, RawSyncsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SyncsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSyncsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSyncsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSyncsClient
        """
        return self._raw_client

    def list(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel:
        """
        List Sources by Destination, specifically given a collection and table

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.syncs.list(
            collection_id="collection_id",
            table_id="table_id",
        )
        """
        _response = self._raw_client.list(collection_id, table_id, request_options=request_options)
        return _response.data

    def get(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionGetSyncResponse:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionGetSyncResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.syncs.get(
            sync_id="sync_id",
        )
        """
        _response = self._raw_client.get(sync_id, request_options=request_options)
        return _response.data

    def update(
        self, sync_id: str, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionUpdateSyncResponse:
        """
        Parameters
        ----------
        sync_id : str

        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionUpdateSyncResponse
            Successful Response

        Examples
        --------
        from scoutos import (
            CollectionDestination,
            Mapping,
            Scout,
            SourceSyncGoogleDriveSettings,
            SyncConfigInput,
        )

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.syncs.update(
            sync_id="sync_id",
            sync_config=SyncConfigInput(
                source_settings=SourceSyncGoogleDriveSettings(),
                destination=CollectionDestination(
                    collection_id="collection_id",
                    table_id="table_id",
                ),
                mapping=Mapping(),
            ),
        )
        """
        _response = self._raw_client.update(sync_id, sync_config=sync_config, request_options=request_options)
        return _response.data

    def delete(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionDeleteSyncResponse:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionDeleteSyncResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.syncs.delete(
            sync_id="sync_id",
        )
        """
        _response = self._raw_client.delete(sync_id, request_options=request_options)
        return _response.data

    def create(
        self, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionCreateSyncResponse:
        """
        Parameters
        ----------
        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionCreateSyncResponse
            Successful Response

        Examples
        --------
        from scoutos import (
            CollectionDestination,
            Mapping,
            Scout,
            SourceSyncGoogleDriveSettings,
            SyncConfigInput,
        )

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.syncs.create(
            sync_config=SyncConfigInput(
                source_settings=SourceSyncGoogleDriveSettings(),
                destination=CollectionDestination(
                    collection_id="collection_id",
                    table_id="table_id",
                ),
                mapping=Mapping(),
            ),
        )
        """
        _response = self._raw_client.create(sync_config=sync_config, request_options=request_options)
        return _response.data

    def execute(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.syncs.execute(
            sync_id="sync_id",
        )
        """
        _response = self._raw_client.execute(sync_id, request_options=request_options)
        return _response.data


class AsyncSyncsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSyncsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSyncsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSyncsClient
        """
        return self._raw_client

    async def list(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel:
        """
        List Sources by Destination, specifically given a collection and table

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.syncs.list(
                collection_id="collection_id",
                table_id="table_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(collection_id, table_id, request_options=request_options)
        return _response.data

    async def get(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionGetSyncResponse:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionGetSyncResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.syncs.get(
                sync_id="sync_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(sync_id, request_options=request_options)
        return _response.data

    async def update(
        self, sync_id: str, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionUpdateSyncResponse:
        """
        Parameters
        ----------
        sync_id : str

        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionUpdateSyncResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import (
            AsyncScout,
            CollectionDestination,
            Mapping,
            SourceSyncGoogleDriveSettings,
            SyncConfigInput,
        )

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.syncs.update(
                sync_id="sync_id",
                sync_config=SyncConfigInput(
                    source_settings=SourceSyncGoogleDriveSettings(),
                    destination=CollectionDestination(
                        collection_id="collection_id",
                        table_id="table_id",
                    ),
                    mapping=Mapping(),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(sync_id, sync_config=sync_config, request_options=request_options)
        return _response.data

    async def delete(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionDeleteSyncResponse:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionDeleteSyncResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.syncs.delete(
                sync_id="sync_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(sync_id, request_options=request_options)
        return _response.data

    async def create(
        self, *, sync_config: SyncConfigInput, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionCreateSyncResponse:
        """
        Parameters
        ----------
        sync_config : SyncConfigInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionCreateSyncResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import (
            AsyncScout,
            CollectionDestination,
            Mapping,
            SourceSyncGoogleDriveSettings,
            SyncConfigInput,
        )

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.syncs.create(
                sync_config=SyncConfigInput(
                    source_settings=SourceSyncGoogleDriveSettings(),
                    destination=CollectionDestination(
                        collection_id="collection_id",
                        table_id="table_id",
                    ),
                    mapping=Mapping(),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(sync_config=sync_config, request_options=request_options)
        return _response.data

    async def execute(
        self, sync_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        Parameters
        ----------
        sync_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.syncs.execute(
                sync_id="sync_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.execute(sync_id, request_options=request_options)
        return _response.data
